==> ts-util-1.5.1.zip: src/ts/util/ReasonedException.java <==
/*
 * ReasonedException class.
 *
 * Copyright (C) 2007 SATOH Takayuki All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package ts.util;

/**
 * RtONXB
 * <br>
 * ȌڍׂȗR{@link java.lang.Enum Enum}IuWFNgɂB
 *
 * @author  V.
 * @version $Revision: 1.1.1.1 $, $Date: 2010-10-16 00:03:44 $
 */
public class ReasonedException extends Exception
{
  /** VAEo[WIDB */
  static final long serialVersionUID = 7047772435026071407L;

  /** R{@link java.lang.Enum Enum}IuWFNgB */
  private Enum reason_ ;

  /**
   * ftHgERXgN^B
   */
  public ReasonedException()
  {
    reason_ = null;
  }

  /**
   * R{@link java.lang.Enum Enum}IuWFNgɂƂ
   * RXgN^B
   *
   * @param  reason R{@link java.lang.Enum Enum}IuWFNgB
   */
  public ReasonedException(Enum reason)
  {
    reason_ = reason;
  }

  /**
   * R{@link java.lang.Enum Enum}IuWFNgƗObZ[W
   * ƂRXgN^B
   *
   * @param  reason R{@link java.lang.Enum Enum}IuWFNgB
   * @param  msg ObZ[WB
   */
  public ReasonedException(Enum reason, String msg)
  {
    super(msg);
    reason_ = reason;
  }

  /**
   * R{@link java.lang.Enum Enum}IuWFNgƗObZ[WA
   * ǑƂȂ{@link java.lang.Throwable Throwable}IuWFNg
   * ƂRXgN^B
   *
   * @param  reason R{@link java.lang.Enum Enum}IuWFNgB
   * @param  msg ObZ[WB
   * @param  cause ̗ǑƂȂ{@link java.lang.Throwable Throwable}
   *           IuWFNgB
   */
  public ReasonedException(Enum reason, String msg, Throwable cause)
  {
    super(msg, cause);
    reason_ = reason;
  }

  /**
   * R{@link java.lang.Enum Enum}IuWFNgƂ̗ǑƂȂ
   * {@link java.lang.Throwable Throwable }IuWFNgɂƂ
   * RXgN^B
   *
   * @param  reason R{@link java.lang.Enum Enum}IuWFNgB
   * @param  cause ̗ǑƂȂ{@link java.lang.Throwable Throwable}
   *           IuWFNgB
   */
  public ReasonedException(Enum reason, Throwable cause)
  {
    super(cause);
    reason_ = reason;
  }

  /**
   * R{@link java.lang.Enum Enum}IuWFNg擾B
   * 
   * @return R{@link java.lang.Enum Enum}IuWFNgB
   */
  public Enum getReason()
  {
    return reason_ ;
  }
}

==> ts-util-1.5.3.zip: src/ts/util/ReasonedException.java <==
/*
 * ReasonedException class.
 *
 * Copyright (C) 2007 SATOH Takayuki All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package ts.util;

/**
 * RtONXB
 * <br>
 * ȌڍׂȗR{@link java.lang.Enum Enum}IuWFNgɂB
 *
 * @author  V.
 * @version $Revision: 1.2 $, $Date: 2011-09-04 15:10:33 $
 */
public class ReasonedException extends Exception
{
  /** VAEo[WIDB */
  static final long serialVersionUID = 7047772435026071407L;

  /** R{@link java.lang.Enum Enum}IuWFNgB */
  private Enum reason_ ;

  /**
   * ftHgERXgN^B
   */
  public ReasonedException()
  {
    reason_ = null;
  }

  /**
   * R{@link java.lang.Enum Enum}IuWFNgɂƂ
   * RXgN^B
   *
   * @param  reason R{@link java.lang.Enum Enum}IuWFNgB
   */
  public ReasonedException(Enum reason)
  {
    reason_ = reason;
  }

  /**
   * R{@link java.lang.Enum Enum}IuWFNgƗObZ[W
   * ƂRXgN^B
   *
   * @param  reason R{@link java.lang.Enum Enum}IuWFNgB
   * @param  msg ObZ[WB
   */
  public ReasonedException(Enum reason, String msg)
  {
    super(msg);
    reason_ = reason;
  }

  /**
   * R{@link java.lang.Enum Enum}IuWFNgƗObZ[WA
   * ǑƂȂ{@link java.lang.Throwable Throwable}IuWFNg
   * ƂRXgN^B
   *
   * @param  reason R{@link java.lang.Enum Enum}IuWFNgB
   * @param  msg ObZ[WB
   * @param  cause ̗ǑƂȂ{@link java.lang.Throwable Throwable}
   *           IuWFNgB
   */
  public ReasonedException(Enum reason, String msg, Throwable cause)
  {
    super(msg, cause);
    reason_ = reason;
  }

  /**
   * R{@link java.lang.Enum Enum}IuWFNgƂ̗ǑƂȂ
   * {@link java.lang.Throwable Throwable }IuWFNgɂƂ
   * RXgN^B
   *
   * @param  reason R{@link java.lang.Enum Enum}IuWFNgB
   * @param  cause ̗ǑƂȂ{@link java.lang.Throwable Throwable}
   *           IuWFNgB
   */
  public ReasonedException(Enum reason, Throwable cause)
  {
    super(cause);
    reason_ = reason;
  }

  /**
   * R{@link java.lang.Enum Enum}IuWFNg擾B
   * 
   * @return R{@link java.lang.Enum Enum}IuWFNgB
   */
  public Enum getReason()
  {
    return reason_ ;
  }

  /**
   * ̃IuWFNg̓e\擾B
   *
   * @return ̃IuWFNg̓e\B
   */
  public String toString()
  {
    StringBuilder buf = new StringBuilder();
    buf.append(getClass().getName());
    buf.append(":[");
    if (getReason() == null) {
      buf.append(null + "");
    }
    else {
      buf.append(getReason().getClass().getName());
      buf.append(".").append(getReason());
    }
    buf.append("]: ").append(getMessage());
    return buf.toString();
  }
}
